<a href='https://www.bsc.es/es'><img src='https://www.cmb.cat/wp-content/uploads/2014/01/BSC-Logo.jpg' align="right" height="100" width="100" /></a>

# Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15731719.svg)](https://doi.org/10.5281/zenodo.15731719)

<!-- badges: end -->

Data and R code to support Fletcher et al. (2025) Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions. *The Lancet Planetary Health*.

To cite this repository:

> *Fletcher C, Moirano G, Alcayna T, Rollock L, Van Meerbeeck CJ, Mahon R, Trotman A, Boodram LL, Browne T, Best S, Lührsen D, Díaz AR, Dunbar W, Lippi CA, Ryan SJ, Colón-González FJ, Stewart-Ibarra AM & Lowe R. (2025). Data and R-code to accompany 'Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions' (v1.0.0). Zenodo. https://doi.org/10.5281/zenodo.15731719*

## Summary

<div align="justify">

**Background** Small islands developing states in the Caribbean are exposed to increasingly frequent and intense extreme climatic events, which can exacerbate outbreaks of climate-sensitive infectious diseases. Few forecasting tools incorporate the compound and cascading effects of multiple delayed climatic indicators on disease outbreak risk. We aimed to create an impact-based modelling framework that employs interactions between climatic predictors to forecast the probability of a climate-sensitive infectious disease outbreak 3 months ahead, and to investigate the compound and cascading effects of temperature and long-lag and short-lag standardised precipitation index (SPI) on dengue outbreak risk in Barbados.

**Methods** We developed a modelling framework to predict the probability of a dengue outbreak in Barbados with a 3-month lead time. We assessed the relationships between dengue incidence and interacting long-lag and short-lag hydrometeorological predictors with confirmed cases from 1999 to 2022 and a Bayesian hierarchical framework accounting for seasonal and interannual variation. With this long–short-lag interaction model, we piloted a dengue early warning system in Barbados for the International Cricket Council Men's Twenty20 World Cup in June, 2024, as a real-world prospective example.

**Findings** We found that a three-way interaction between the 3-month averaged mean temperature anomaly lagged by 3 months, 6-month standardised precipitation index (SPI-6) lagged by 5 months, and SPI-6 lagged by 1 month best predicted dengue outbreak risk in Barbados. Our findings showed that long-lag dry (lagged by 5
months), mid-lag hot (lagged by 3 months), and short-lag wet (lagged by 1 month) conditions led to the greatest dengue risk. During cross-validation from 2012 to 2022, the model exhibited a true positive rate (TPR) of 81% and a false positive rate (FPR) of 29%, outperforming a baseline model representing standard practice with a TPR of 68% and an FPR of 48%. For the Twenty20 World Cup, the model predicted a 95% outbreak probability due to epidemiological and climatic conditions, which was shared with the Barbados Ministry of Health and Wellness ahead of the tournament.

**Interpretation** Our impact-based modelling framework with long-lag and short-lag interactions explicitly accounted for the compound and cascading effects of drought, heat, and excessively wet conditions on dengue outbreak risk in Barbados. The model is being implemented in a national dengue early warning system with ongoing monitoring and evaluation to ensure its reliability and usefulness in operational contexts. Future work could explore the applicability of this methodology to modelling or predicting climate-sensitive infectious diseases in other endemic settings.


## Structure
This repository contains processed data suitable for building the models described in the associated publication, along with the code used for data processing, analysis, and visualisation of the model outputs.

<pre>
<span style="color:#007acc;"><b>data</b></span>                                 Processed datasets for analysis, with associated metadata
<span style="color:#007acc;"><b>functions</b></span>                            Functions for conducting analysis and producing visualisations
<span style="color:#007acc;"><b>outputs</b></span>                              Outputs from modelling, cross validation and prediction
<span style="color:#007acc;"><b>supplementary</b></span>                        Scripts for supplementary materials and sensitivity analysis
<span style="color:#007acc;"><b>01_data_exploration.R</b></span>                Script for exploring and visualising data
<span style="color:#007acc;"><b>02_model_fitting.R</b></span>                   Script for fitting long-short-lag interaction models in INLA
<span style="color:#007acc;"><b>03_model_selection.R</b></span>                 Script for selecting candidate models
<span style="color:#007acc;"><b>04_cross_validation.R</b></span>                Script for performing rolling-origin cross validation
<span style="color:#007acc;"><b>05_combined_climate_contribution.R</b></span>   Script for quantifying combined contribution of climate covariates
<span style="color:#007acc;"><b>06_t20_cricket_forecast.R</b></span>            Script for generating dengue outbreak risk forecast for Twenty20 Cricket World Cup
</pre>


## Contributors
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/fletcher-chloe">Chloe Fletcher</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0002-6705-7605">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/moirano-giovenale">Giovenale Moirano, PhD</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0001-8748-3321">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/alcayna-tilly">Tilly Alcayna</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0003-1237-1039">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Leslie Rollock</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Cédric J Van Meerbeeck</strong>&nbsp;
  <a href="https://orcid.org/0000-0003-0833-0664">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Roché Mahon</strong>&nbsp;
  <a href="https://orcid.org/0000-0001-9621-7033">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Adrian Trotman</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3099-8671">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Laura-Lee Boodram</strong>&nbsp;
  <a href="https://orcid.org/0000-0001-5535-3127">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Tia Browne</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Sabu Best</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/luhrsen-daniela-sofie">Daniela Lührsen</a></strong>&nbsp;
  <a href="https://orcid.org/0009-0002-6340-5964">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Avriel R Díaz</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3108-7140">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Willy Dunbar</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-9134-9288">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Catherine A Lippi</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-7988-0324">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Sadie J Ryan</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-4308-6321">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Felipe J Colón-González</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-9671-3405">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Anna Stewart-Ibarra</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3383-4672">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/lowe-rachel">Professor Rachel Lowe</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0003-3939-7343">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>
</span>

</div>
